from RG.xlsread import *
from RG.regress import *
from RG.reset import *

from RG.PCA import *
from RG.PLS import *
from RG.VIP import *
from RG.mbPLS import *
from RG.cPCA import *
from RG.LDA import *
from RG.PCA_ellipse import *
from RG.ICA import *
from RG.MCR import *

from RG.colorspectra import *
from RG.axaline import *
from RG.lags import *
from RG.DTW import *
from RG.DTW_batch import *

from RG.correlated_matrix import *
from RG.corr_reorder import *
from RG.pcorrcoef import *
from RG.R2 import *
from RG.normplot import *
from RG.VIF import *

from RG.center import *
from RG.autoscale import *
from RG.baseline import *
from RG.SNV import *
from RG.MSC import *
from RG.EMSC import *
from RG.savitzky_golay import *
from RG.detrend import *

from RG.email import *










